<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>Neu</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Jede Runde</numerusform>
            <numerusform>Jede %1. Runde</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Waffenzusammenstellung bearbeiten</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Ungültige Waffenzusammenstellung</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Spielprofile bearbeiten</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 wurde aus deiner Ignorierliste entfernt</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 wurde in deine Ignorierliste aufgenommen</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 wurde aus deiner Freundesliste entfernt</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 wurde in deine Freundesliste aufgenommen</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Server konnte nicht gestartet werden</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Datei %1 konnte nicht gespeichert werden</translation>
    </message>
    <message>
        <source>new</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Bitte wähle einen Eintrag aus der obigen Liste</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>de.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Demodatei %1 konnte nicht geöffnet werden</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Motiv</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Klein</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groß</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Höhle</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Verrückt</translation>
    </message>
    <message>
        <source>Tunnel size</source>
        <translation type="obsolete">Tunnelgröße</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Kleine Tunnel</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Mittlere Tunnel</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Große Tunnel</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Kleine schwebende Inseln</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Mittlere schwebende Inseln</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Große schwebende Inseln</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Spielname</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Der Server wurde nicht gefunden. Bitte überprüfe deine Einstellungen.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Verbindungsaufbau abgelehnt</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Gegangen wegen: </translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Raum geschlossen</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Du wurdest hinausgeworfen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation>Dein Spitzname &apos;%1&apos; wurde
auf Hedgewars.org registriert.

Bitte gib dein Passwort ein oder
wähle einen anderen Spitznamen:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 hat den Raum betreten</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 ist beigetreten</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 ist gegangen (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 ist gegangen</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf meldete einen Fehler beim Rendern des Textes, dies liegt vermutlich an einem Fehler in freetype2. Es wird empfohlen die freetype Bibliothek auf den neuesten Stand zu bringen.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Servernachricht:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Servernachricht festlegen</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Zwischenspeicher leeren</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Verbinde ...</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Der Preis für den besten Schuss geht an &lt;b&gt;%1&lt;/b&gt; mit &lt;b&gt;%2&lt;/b&gt; Punkten.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Der blutigste Kämpfer ist &lt;b&gt;%1&lt;/b&gt; mit &lt;b&gt;%2&lt;/b&gt; Opfer in einer Runde.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Der blutigste Kämpfer ist &lt;b&gt;%1&lt;/b&gt; mit &lt;b&gt;%2&lt;/b&gt; Opfern in einer Runde.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Insgesamt fand &lt;b&gt;%1&lt;/b&gt; Igel ein trauriges Ende in dieser Runde.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Insgesamt fanden &lt;b&gt;%1&lt;/b&gt; Igel ein trauriges Ende in dieser Runde.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Lokales Spiel</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Netzwerkspiel</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Bitte wähle einen Eintrag aus der Liste aus</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Steuerung</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Eigener Server (LAN oder Internet)</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Offizieller Server</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Neues Team</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Team bearbeiten</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Team löschen</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation>Neue Waffenzusammenstellung</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation>Waffenzusammenstellung bearbeiten</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation>Waffenzusammenstellung löschen</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Neuer Dateiname:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Datei kann nicht umbenannt werden in</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Datei kann nicht gelöscht werden</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Bitte einen Eintrag aus der Liste auswählen</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Betreten</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Verwalten</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Raumname:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Dieses Spiel wartet im Augenblick auf Mitspieler.
Du kannst beitreten und mitspielen oder zusehen, sobald das Spiel beginnt.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Dieses Spiel läuft gerade.
Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende ist.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 ist der Besitzer dieses Raums und kann die Einstellungen anpassen und die Runde starten.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Zufallskarte</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Spiele können  auf vorgefertigten oder zufälligen Karten stattfinden.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Spielprofile geben allgemeine Dinge einer Runde vor, etwa die Rundenzeit, Sudden Death oder Vampirismus.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Waffenzusammenstellungen bestimmen, welche Waffen wann und in welchen Mengen zur Verfügung stehen.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Es befindet sich %1 Spieler in diesem Raum.</numerusform>
            <numerusform>Es befinden sich %1 Spieler in diesem Raum.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Es nimmt %1 Team in diesem Raum teil.</numerusform>
            <numerusform>Es nehmen %1 Teams in diesem Raum teil.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Bitte einen Raumnamen eingeben</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Bitte einen Raum aus der Liste auswählen</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Zufallslabyrinth</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation>Zufällige Minen Positionen</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>80% des ausgeteilten Schadens werden in Lebenspunkte gewandelt</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Teile den Schmerz Deines Gegners, teile dessen verursachten Schaden</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Deine Igel können sich nicht bewegen, gib Dein Bestes im Fernkampf</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Zufall</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Verteidige Dein Fort und zerstöre das des Gegners, maximal zwei Teamfarben!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Die Teams starten auf gegenüberliegenden Terrainseiten, maximal zwei Teamfarben!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Die Landschaft ist nicht zerstörbar!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Einfügen eines unzerstörbaren Kartenrand</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Verringerte Schwerkraft</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Zielfhilfe durch Laservisier</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Alle Igel haben ein eigenes Schutzschild</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Gespielt wird in zufälliger Reihenfolge.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Beschütze deinen König! Ohne ihn hast du verloren.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Platziere deine Igel selbständig vor Rundenbeginn.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Alle Teams mit gleicher Farbe teilen sich den gleichen Waffenvorrat.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Platziere keine Bauträger auf Zufallskarten.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Einfaches Spiel (Eine schnelle Runde gegen den PC, Einstellungen werden automatisch gewählt)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Mehrspieler (Spiele gegen deine Freunde oder Computergegner)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Trainingsmodus (Verbessere dein Können in verschiedenen Trainingsmissionen). IN ENTWICKLUNG</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demos (Wiedergabe einer gespeicherten Demo)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Laden (eines vorher gespeicherten Spiels)</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Rauswerfen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Zugang beschränken</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Teamzugang beschränken</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Verbannen</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Folgen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Als Freund hinzufügen</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Nicht mehr ignorieren</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Als Freund entfernen</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Klänge im Spiel</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>FPS anzeigen</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Alternativen Schaden anzeigen</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Musik im Spiel</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Frontend im Vollbild</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Datum und Uhrzeit an Aufnahmedatei anhängen</translation>
    </message>
    <message>
        <source>Check for updates at startup</source>
        <translation>Beim Start nach neuen Versionen suchen</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation>Niedrige Qualität</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Kurzinfos für Waffen anzeigen</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Klänge im Frontend</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Musik im Frontend</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Animationen im Frontend</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>Zufallskarte...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Mensch</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Stufe</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Systemstandard)</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Mission</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>Zufallslabyrinth...</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Teammitglieder</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Tastenkombinationen</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Festung</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Teams</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Audio-/Grafik-Einstellungen</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Waffen</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Netzwerkspiel</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Spielende Teams</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Spielmodifikatoren</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Grundeinstellungen</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Teameinstellungen</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Verschiedenes</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Dieses Programm ist unter der GNU General Public License veröffentlicht</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Entwickler:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafiken:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Übersetzer:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Besonderer Dank geht an:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Waffen</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS-Limit</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Spitzname im Netz</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Servername:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Serverport:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Sounds:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Ausgangslautstärke</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Prozentualer Schaden</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Rundenzeit</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Anfangslebenspunkte</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Runden bis Sudden Death</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>Minenzündzeit</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Minen</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Spielprofil:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Kistenabwurf</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Spielprofil</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% Blindgänger</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Grab</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Flagge</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Stimme</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Spiel neu starten, um Änderungen zu übernehmen</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Pulverfässer</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Diese SVN-Kopie ist noch in Entwicklung und sie ist mit anderen Versionen vielleicht nicht kompatibel.
Einige Dinge könnten nicht funktionieren oder unvollständig sein. Benutzung auf eigene Gefahr!</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>unbenannt</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Verbindung zum Server wurde unterbrochen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Das Verzeichnis:
%1
konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Waffen</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>Das Standard-Waffen-Set kann nicht editiert werden</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>Das Standard-Waffen-Set kann nicht gelöscht werden</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Soll dieses Waffen-Set wirklich gelöscht werden?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Verzeichnis %1 konnte nicht angelegt werden</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Bitte gib deinen Spitznamen ein</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation>Los!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Server starten</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Verbinden zu ...</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Demo abspielen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Bereit</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Zufallsteam</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Raumname</translation>
    </message>
    <message>
        <source>C</source>
        <translation>Sp.</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T.</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Besitzer</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Regeln</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Waffen</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Bewaffnung</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Nachschub</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Kisteninhalt</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Verzögerungen</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Server %1 konnte nicht gestartet werden.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Engine konnte nicht gestartet werden: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampirismus</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Artillerie</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Festungs-Modus</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Teams getrennt aufstellen</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Unzerstörbares Terrain</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Randbegrenzung einfügen</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Verringerte Schwerkraft</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Laservisier</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Unverwundbarkeit</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation>Minen hinzufügen</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Zufällige Reihenfolge</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Schützt den König</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Igel platzieren</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Gemeinsames Arsenal</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Keine Bauträger</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>down</source>
        <translation>Runter</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>Angreifen</translation>
    </message>
    <message>
        <source>put</source>
        <translation>Platzieren</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>Wechseln</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>Igel finden</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>Munitions-Menü</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>Slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>Slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>Slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>Slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>Slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>Slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>Slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>Slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>Slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>Timer 1 Sek.</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>Timer 2 Sek.</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>Timer 3 Sek.</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>Timer 4 Sek.</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>Timer 5 Sek.</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>Lautstärke verringern</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>Lautstärke erhöhen</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>Modus ändern</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>Bildschirmfoto</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>Igel 
Statistik</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>Chatten</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>Chatverlauf</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>Genaues Zielen</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>Vergrößern</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>Verkleinern</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>Weiter Sprung</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>Hoher Sprung</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Grundsteuerung</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Waffensteuerung</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Kamera- und Zeigersteuerung</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Bewege und ziele mit deinen Igeln:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Überwinde Abgründe und Hindernisse mit Sprüngen:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Benutze deine gewählte Waffe oder Werkzeug:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Wähle eine Waffe oder einen Zielpunkt mit dem Cursor:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Wähle den zu steuernden Igel (falls möglich):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Wähle eine Waffe oder Werkzeug aus:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Setze den Zeitzünder von verschiedenen Waffen:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation> Bewege die Kamera zum aktiven Igel:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Bewege den Zeiger oder die Kamera ohne die Maus:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Verändere den Bildausschnitt:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Spreche mit anderen Spielern:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pausiere oder verlasse das Spiel:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Ändere die Lautstärke im Spiel:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Schalte den Vollbildmodus um:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Erstelle ein Bildschirmfoto:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Ändere die Informationen über Igeln:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Achse</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Hoch)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Runter)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Cooliehat</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Links)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Rechts)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Taste</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Tastatur</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Maus: Linke Taste</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Maus: Mittlere Taste</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Maus: Rechte Taste</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Maus: Mausrad hoch</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Maus: Mausrad runter</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Rückstelltaste</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulator</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Clear</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Eingabetaste</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Leertaste</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Entf</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Ziffernblock 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Ziffernblock 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Ziffernblock 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Ziffernblock 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Ziffernblock 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Ziffernblock 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Ziffernblock 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Ziffernblock 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Ziffernblock 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Ziffernblock 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Ziffernblock ,</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Ziffernblock /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Ziffernblock *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Ziffernblock -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Ziffernblock +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Gleich</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Runter</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Einfg</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Pos1</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Bild hoch</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Bild runter</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Numlock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Feststelltaste</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Rollen</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Rechte Umschalttaste</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Linke Umschalttaste</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Strg rechts</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Strg links</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Alt rechts</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Alt links</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Meta rechts</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Meta links</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A-Taste</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B-Taste</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X-Taste</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y-Taste</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>Linke Schultertaste</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>Rechte Schultertaste</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Zurück-Taste</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Start-Taste</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Linker Analogstick</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Rechter Analogstick</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Linker Analogstick (Rechts)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Linker Analogstick (Links)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Linker Analogstick (Runter)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Linker Analogstick (Hoch)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Linker Auslöser</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Rechter Auslöser</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Rechter Analogstick (Runter)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Rechter Analogstick (Hoch)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Rechter Analogstick (Rechts)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Rechter Analogstick (Links)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>Steuerkreuz</translation>
    </message>
</context>
</TS>
